summary refs log tree commit diff
diff options
context:
space:
mode:
authorRyan Schmidt <github@ryandesign.com>2015-02-14 04:10:23 -0600
committerRyan Schmidt <github@ryandesign.com>2015-02-14 04:10:23 -0600
commitd9aa2b784d914ae99c7d9bbaf83d06f1b9dbd04e (patch)
treee6a1ac6a9d494705c47e7193214e3dc3594fe7ef
parentcffcbc02de504d84e1c2677bb525c00b03e04f53 (diff)
downloadyoutube-dl-d9aa2b784d914ae99c7d9bbaf83d06f1b9dbd04e.tar.gz
youtube-dl-d9aa2b784d914ae99c7d9bbaf83d06f1b9dbd04e.tar.xz
youtube-dl-d9aa2b784d914ae99c7d9bbaf83d06f1b9dbd04e.zip
Support NBC Nightly News broadcasts
-rw-r--r--youtube_dl/extractor/nbc.py27
1 files changed, 22 insertions, 5 deletions
diff --git a/youtube_dl/extractor/nbc.py b/youtube_dl/extractor/nbc.py
index f840f6532..3e3de9e2d 100644
--- a/youtube_dl/extractor/nbc.py
+++ b/youtube_dl/extractor/nbc.py
@@ -54,7 +54,7 @@ class NBCIE(InfoExtractor):
 class NBCNewsIE(InfoExtractor):
     _VALID_URL = r'''(?x)https?://www\.nbcnews\.com/
         ((video/.+?/(?P<id>\d+))|
-        (feature/[^/]+/(?P<title>.+)))
+        ((?P<program>feature|nightly-news)/[^/]+/(?P<title>.+)))
         '''
 
     _TESTS = [
@@ -89,6 +89,16 @@ class NBCNewsIE(InfoExtractor):
                 'description': 'md5:757988edbaae9d7be1d585eb5d55cc04',
             },
         },
+        {
+            'url': 'http://www.nbcnews.com/nightly-news/video/nightly-news-with-brian-williams-full-broadcast-february-4-394064451844',
+            'md5': 'b5dda8cddd8650baa0dcb616dd2cf60d',
+            'info_dict': {
+                'id': 'sekXqyTVnmN3',
+                'ext': 'mp4',
+                'title': 'Nightly News with Brian Williams Full Broadcast (February 4)',
+                'description': 'md5:1c10c1eccbe84a26e5debb4381e2d3c5',
+            },
+        },
     ]
 
     def _real_extract(self, url):
@@ -107,12 +117,19 @@ class NBCNewsIE(InfoExtractor):
                 'thumbnail': find_xpath_attr(info, 'media', 'type', 'thumbnail').text,
             }
         else:
             # "feature" pages use theplatform.com
             title = mobj.group('title')
             webpage = self._download_webpage(url, title)
-            bootstrap_json = self._search_regex(
-                r'var bootstrapJson = ({.+})\s*$', webpage, 'bootstrap json',
-                flags=re.MULTILINE)
+            program = mobj.group('program')
+            if program == 'feature':
+                bootstrap_json = self._search_regex(
+                    r'var bootstrapJson = ({.+})\s*$', webpage, 'bootstrap json',
+                    flags=re.MULTILINE)
+            else:
+                # nightly-news
+                bootstrap_json = self._search_regex(
+                    r'var playlistData = ({.+});\s*$', webpage, 'playlist data',
+                    flags=re.MULTILINE)
             bootstrap = json.loads(bootstrap_json)
             info = bootstrap['results'][0]['video']
             mpxid = info['mpxId']
@@ -107,12 +117,19 @@ class NBCNewsIE(InfoExtractor):
             }
         else:
-            # "feature" pages use theplatform.com
+            # "feature" and "nightly-news" pages use theplatform.com
             title = mobj.group('title')
             webpage = self._download_webpage(url, title)